@@ -2,30 +2,32 @@
 #'  enrichment analysis for one species
 #' @name graphGOspecies
 #' @description graphGOspecies is a function to create undirected graphs using two options:
+#'  \loadmathjax
 #'
-#' 1.) Nodes are GO terms such as biological processes and the edges are features.
-#'  First, edges weights  are calculated as the intersection where cat(U) n cat(V) represents
-#'  categories where the GO terms U and V are. While nBP is the total number of biological processes
-#'  represented by the GO terms (1).Finally node weights are calculated as sum of all w(e) where the node is participant (2)
-#'  (Please be patient, it requires a long time to finish).
-#'  \deqn{w(e) = \frac{|cat(U) n cat(V)|}{|nBP|}}{%
-#'  w(e) = |cat(U) n cat(V)| / |nBP| (1)}
+#'  Categories option:
+#'
+#'  The nodes \mjseqn{(V)} represent groups of gene lists (categories), and the edges \mjseqn{(E)} represent GO terms co-occurring between pairs of categories. More specifically,
+#'  Two categories: \mjseqn{u,v \epsilon V } are connected by an edge \mjseqn{e=(u,v)}.the edge weights \mjseqn{w(e)} are defined as the ratio of the number of GO terms co-occurring
+#'  between two categories. Edge weights w(e) are defined as the ratio of the number of GO terms (e.g. biological processes) co-occurring between two categories
+#'   \mjseqn{BP_{u} \ n  BP_{v}} compared to the total number of GO terms available.
+#'  A node weight \mjseqn{K_{w}(u)} is defined as the sum of the edge weights where the node u is a participant. Thus, the node weight represents how frequently
+#'   GO terms are reported and expressed in a biological phenomenon.
+#'
+#'  \mjsdeqn{w(e) = \frac{\mid BP_{u} n {BP_{v}}\mid}{\mid BP\mid}} (1)
+#'
+#'  \mjsdeqn{K_{w} = \sum_{{v} \epsilon {V}}{w(u,v)}} (2)
 #'
 #'
-#'  \deqn{K_w(U) = \sum(w(U,V))}{%
-#'  K_w(U) = sum(w(U,V)) (2)}
+#'  GO option:
 #'
+#'  The nodes \mjseqn{{V}} represent GO terms and the edges \mjseqn{{E}'} represent categories where a pair of GO terms co-occur. More specifically,
+#'  two GO terms are connected by an edge \mjseqn{{e}'=({u},{v}')}. the edge weight \mjseqn{{w}'({e}')} corresponds to the number of categories co-occurring
+#'   the GO terms \mjseqn{{u}} and \mjseqn{{v}'},compared with the total number of GO terms (Equation 3). A node weight \mjseqn{{K}'_w({u}')} is defined,in this case the weight
+#'  represents the importance of a GO term (more frequent co-occurring).(Please be patient, it requires a long time to finish).
 #'
-#' 2.) Nodes are features, the edges are the number of GO terms such as biological processes in your gene lists.
-#' In this case the edge weights are calculated as the number of biological processes shared by a category expressed as BP(U) n BP(V)
-#' nBP is the total number of biological processes (3). FInally, the node weights is calculated as the sum of all w(e) where the node is participant (4)
-#'
-#'  \deqn{w(e) = \frac{|BP(U) n BP(V)|}{|nBP|}}{%
-#'  w(e) = |BP(U) n BP(V)| / |nBP| (3)}
-#'
-#'  \deqn{K_w(U) = \sum(w(U,V))}{%
-#'  K_w(U) = sum(w(U,V)) (4)}
+#'  \mjsdeqn{{w}'({e}')=\frac{\mid{Cu}'\cap  {Cv}'\mid}{\mid BP \mid}} (3)
 #'
+#'  \mjsdeqn{{K}'_w({u}')=\sum_{{v}'\epsilon {V}'}{{w}'({u}',{v}')}} (4)
 #'
 #' @param df A data frame with the results of a functional enrichment analysis for
 #'  a species with an extra column "feature" with the features to be compared
@@ -36,9 +38,46 @@
 #' @param saveGraph logical, if \code{TRUE} the function will allow save the graph in graphml format
 #' @param outdir This parameter will allow save the graph file in a folder described here (e.g: "D:").This parameter only
 #' works when saveGraph=TRUE
+#' @param filename The name of the graph filename to be saved in the outdir detailed by the user.This parameter only
+#' works when saveGraph=TRUE
+#'
+#' @return This function will return a list with two slots: edges and nodes.
+#'
+#'  (Categories):
+#'   Edges list columns:
+#'   \tabular{rr}{
+#'   Column \tab Description \cr
+#'   SOURCE and TARGET \tab The source and target categories (Nodes in the edge) \cr
+#'   FEATURES_N \tab The number of GO terms between the categories \cr
+#'   WEIGHT \tab Edge weight \cr
+#'   FEATURES \tab GO terms available for both nodes \cr
+#'   }
+#'
+#'   Node list columns:
+#'   \tabular{rr}{
+#'   Column \tab Description \cr
+#'   feature\tab Category name \cr
+#'   GO_count  \tab GO terms counts for the node \cr
+#'   WEIGHT  \tab Node weight \cr
+#'   }
+#'
+#'  (GO):
+#'
+#'   Edges list columns:
+#'   \tabular{rr}{
+#'   Column \tab Description \cr
+#'   SOURCE and TARGET \tab The source and target GO terms (Nodes in the edge) \cr
+#'   FEATURE \tab The number of Categories where both GO Terms were found \cr
+#'   WEIGHT \tab Edge weight \cr
+#'   }
+#'   Node list columns:
+#'
+#'   \tabular{rr}{
+#'   Column \tab Description \cr
+#'   GO \tab GO term node name \cr
+#'   GO_WEIGHT \tab Node weight \cr
+#'   }
 #'
-#' @return This function will return a list with two slots: edges and nodes. Edges represents an edge list and their weights and
-#'  nodes which represents the nodes and their respective weights
 #' @examples
 #'
 #' #Loading example datasets
@@ -52,18 +91,24 @@
 #'                      option = "Categories",
 #'                      numCores=1,
 #'                      saveGraph=FALSE,
-#'                      outdir = NULL)
+#'                      outdir = NULL,
+#'                      filename=NULL)
 #'
 #' @importFrom utils combn
 #' @importFrom igraph graph_from_data_frame write.graph
 #' @importFrom parallel makeCluster parLapplyLB stopCluster detectCores
 #' @importFrom stats aggregate
 #' @importFrom stringr str_count
+#' @import mathjaxr
 #' @export
 
-graphGOspecies <- function(df, GOterm_field, option = "Categories", numCores=2,saveGraph = FALSE,outdir = NULL) {
+graphGOspecies <- function(df, GOterm_field, option = "Categories", numCores=2,
+                           saveGraph = FALSE,outdir = NULL,filename=NULL) {
   x_det <- NULL
   x_det <- parallel::detectCores()
+
+  df <- df[,c("feature",GOterm_field)]
+
   if (is.null(option) | !option %in% c("Categories","GO")) {
     stop("Please use a valid option")
   }
@@ -76,6 +121,13 @@ graphGOspecies <- function(df, GOterm_field, option = "Categories", numCores=2,s
     stop("Please select saveGraph=TRUE to save your graph")
   }
 
+  if (isTRUE(saveGraph) & !is.null(outdir) & is.null(filename)) {
+    message(paste("Your filename will be saved as GO.graphml or CAT.graphml
+            dependent of the option selected in the path:",outdir))
+    message("please provide a filename if you want to avoid this behavior")
+  }
+
+
   if (numCores > x_det) {
     stop("Number of cores exceed the maximum allowed by the machine,
          use a coherent number of cores such as four")
@@ -247,22 +299,46 @@ graphGOspecies <- function(df, GOterm_field, option = "Categories", numCores=2,s
 
   if (isTRUE(saveGraph)) {
     if (isTRUE(option == "GO")) {
+      if(is.null(filename)){
 
-      message(paste("saving ",paste0(outdir, "/", "GO.graphml")))
-      x1 <- igraph::graph_from_data_frame(res$edges, directed = FALSE,vertices =  res$nodes)
-      igraph::write.graph(x1,
+        message(paste("saving ",paste0(outdir, "/", "GO.graphml")))
+        x1 <- igraph::graph_from_data_frame(res$edges, directed = FALSE,vertices =  res$nodes)
+        igraph::write.graph(x1,
                           file = paste0(outdir, "/", "GO.graphml"),
                           format = "graphml")
+      } else {
+
+        message(paste("saving ",paste0(outdir, "/",filename,".graphml")))
+        x1 <- igraph::graph_from_data_frame(res$edges, directed = FALSE,vertices =  res$nodes)
+        igraph::write.graph(x1,
+                            file = paste0(outdir, "/",filename,".graphml"),
+                            format = "graphml")
+
+      }
     } else if(option =="Categories") {
+      if(is.null(filename)){
 
-      x2 <- igraph::graph_from_data_frame(res$edges, directed = FALSE,vertices = res$nodes)
-      message(paste("saving ",paste0(outdir, "/", "CAT.graphml")))
+        x2 <- igraph::graph_from_data_frame(res$edges, directed = FALSE,vertices = res$nodes)
+        message(paste("saving ",paste0(outdir, "/", "CAT.graphml")))
 
-      igraph::write.graph(x2,
-                          file = paste0(outdir, "/", "CAT.graphml"),
-                          format = "graphml")
+        igraph::write.graph(x2,
+                            file = paste0(outdir, "/", "CAT.graphml"),
+                            format = "graphml")
+      } else {
+
+        x2 <- igraph::graph_from_data_frame(res$edges, directed = FALSE,vertices = res$nodes)
+        message(paste("saving ",paste0(outdir, "/",filename,".graphml")))
+
+        igraph::write.graph(x2,
+                            file = paste0(outdir, "/","filename",".graphml"),
+                            format = "graphml")
+
+      }
     }
+  } else {
+    message("Saving as edges and node lists")
   }
 
+
   return(res)
 }
