@@ -2,35 +2,48 @@
 #'  enrichment analysis to compare two species and a series of categories
 #' @name graph_two_GOspecies
 #' @description graph_two_GOspecies is a function to create undirected graphs
-#'  to compare GO terms between two species using two options:
-#'  1.) Nodes are GO terms such as biological processes and the edges represent
-#'  features for a species since the method creates a graph per species
-#'  as well as shared GO terms between them.
-#'  Edge weights are calculated as the intersection where cat(U) n cat(V)
-#'  represents categories where the GO terms U and V are. nBP is the total number
-#'  of biological processes represented by the GO terms (1). Node weights are
-#'   calculated as the sum of all w(e) where the node is a participant (2)
-#'    in each species and a shared GO terms(k) graphs.
+#'  \loadmathjax
 #'
-#'  (Please be patient, it requires a long time to finish).
-#'  \deqn{w(e) = \frac{|cat(U) n cat(V)|}{|nBP|}}{%
-#'  w(e) = |cat(U) n cat(V)| / |nBP| (1)}
+#'  The graph_two_GOspecies is an analog of the graphGOspecies function, and it has the same options (" Categories " and " GO ").
+#'  Nevertheless, the way in which the edge and node weights are calculated is slightly different. Since two species are compared,
+#'  three possible graphs are available \mjseqn{{G}_1,\, {G}_2}, and \mjseqn{{G}_3 }. \mjseqn{{G}_1}, and \mjseqn{{G}_2 } represent each of the species analyzed
+#'  and \mjseqn{{G}_3} is a subgraph of \mjseqn{{G}_1,\, {G}_2}, which contains the GO terms or Categories co-ocurring between both species.
 #'
-#'  \deqn{K_w(U) =  \sum(\sum(w(U,V)k=,1,k))}{%
-#'  K_w(U) =  sum(sum(w(U,V),k=,1,k)) (2)}
+#'  Categories option:
+#'  (Weight): The nodes \mjseqn{(V)} represent groups of gene lists (categories), and the edges \mjseqn{(E)} represent GO terms co-occurring between pairs of categories
+#'  and the weight of the nodes provides a measure of how a GO term is conserved between two species and a series of categories but it is biased
+#'  to categories.
+#'
+#'  \mjsdeqn{\widehat{K}_w(u)=\sum_{v \epsilon V_1}^{}w(u,v) + \sum_{v \epsilon V_2}^{}w(u,v)} (5)
+#'
+#' (shared weight): The nodes \mjseqn{(V)} represent groups of gene lists (categories), and the edges \mjseqn{(E)} represent GO terms co-occurring between pairs of categories that are only
+#'  shared between species. This node weight  \mjseqn{{K}_s} is computed from a shared weight of edges \mjseqn{{s}}, where \mjseqn{{N}1} and \mjseqn{{N}2} are the set of GO terms associated
+#'   with the edge \mjseqn{e = (u,v) } for species 1 and 2, respectively. Therefore the node shared weight \mjseqn{{K}_s(u)}  is the sum of \mjseqn{{s}}.
 #'
 #'
-#'  2.) Nodes are features and edges are GO terms available in the set of graphs (k) which consist of each species graphs and a shared GO terms graph (k).
-#'  Two edges weights are calculated. First, edges weights are calculated as number of BP in the feature in comparison with the total number of GO terms available (3).
-#'  Second, a shared weight is calculated for interactions shared between two species. Finally, node weights are calculated as the sum of all w(e) where the node is a participant (2) in each  species and a shared GO terms(k) graphs
 #'
-#'  \deqn{w(e) = \frac{|BP(U) n BP(V)|}{|nBP|}}{%
-#'  w(e) = |BP(U) n BP(V)| / |nBP| (3)}
+#'  \mjsdeqn{s(e) = \frac{\mid {N1} \ n \ {N2} \mid}{\mid {N1} \bigcup {N2} \mid}} (6)
 #'
-#'  \deqn{K_w(U) =  \sum(\sum(w(U,V)k=,1,k))}{%
-#'  K_w(U) =  sum(sum(w(U,V),k=,1,k)) (4)}
+#'  \mjsdeqn{{K}_s(u)=\sum_{v \epsilon (V_1  \bigcup V_2) }^{}{s(u,v)}} (7)
 #'
 #'
+#'  (combined weight): This node weight  \mjseqn{{K}_c(u)} is a combination of the weight and the shared weight. The idea of this combined weight is
+#'   to find categories with more frequent GO terms co-ocurring in order to observe functional similarities between two species with a balance of GO terms co-occurring among
+#'    gene lists (categories) and the two species. This node weight varies from -1 (categories with GO terms found only in one species and few categories) to 1
+#'    (categories with GO terms shared widely between species and among other categories). the combined node weight \mjseqn{{K}_c} is defined as the sum of the min-max normalized weights
+#'     \mjseqn{\widehat{K}_w} and \mjseqn{{K}_s} minus 1.
+#'
+#'  \mjsdeqn{minmax(y)=\frac{y-min(y)}{max(y)-min(y)}} (8)
+#'  \mjsdeqn{{K}_c(u)= minmax(\widehat{K}_w(u)) + minmax({K}_s(u)) - 1 } (9)
+#'
+#'
+#'  GO option:
+#'  Given there are three possible graphs are available \mjseqn{{G}_1,\, {G}_2}, and \mjseqn{{G}_3}.  \mjseqn{{G}_1}, and \mjseqn{{G}_2} represent each of the species analyzed
+#'  and \mjseqn{{G}_3} is a subgraph of \mjseqn{{G}_1,\, {G}_2}, which contains the GO terms or Categories co-ocurring between both species. For this case, Nodes are GO terms and edges are
+#'  categories where a GO terms is co-ocurring. This weight is similar to the GO weight calculated for graphGOspecies function. it is calculated as the equation 5.
+#'
+#'  \mjsdeqn{\widehat{K}_w(u)=\sum_{v \epsilon V_1}^{}w(u,v) + \sum_{v \epsilon V_2}^{}w(u,v)} (5)
+#'
 #' @param x is a list obtained as output of the comparegOspecies function
 #' @param GOterm_field This is a string with the column name of the GO terms (e.g; "Functional_Category")
 #' @param species1 This is a string with the species name for species 1 (e.g; "H. sapiens")
@@ -42,6 +55,9 @@
 #' @param saveGraph logical, if \code{TRUE} the function will allow save the graph in graphml format
 #' @param outdir This parameter will allow save the graph file in a folder described here (e.g: "D:").This parameter only
 #'  works when saveGraph=TRUE
+#' @param filename The name of the graph filename to be saved in the outdir detailed by the user.This parameter only
+#' works when saveGraph=TRUE
+#'
 #' @examples
 #'
 #' GOterm_field <- "Functional_Category"
@@ -56,14 +72,55 @@
 #'           numCores=1,
 #'           saveGraph = FALSE,
 #'           option= "Categories",
-#'           outdir = NULL)
+#'           outdir = NULL,
+#'           filename= NULL)
+#'
+#' @return This function will return a list with two slots: edges and nodes.
+#'  (Categories):
+#'   Edges list columns:
+#'   \tabular{rr}{
+#'   Column \tab Description \cr
+#'   SOURCE and TARGET \tab The source and target categories (Nodes in the edge) \cr
+#'   GO_N \tab The number of GO terms between the categories \cr
+#'   WEIGHT \tab Edge weight \cr
+#'   GO \tab GO terms available for both nodes \cr
+#'   SP1 \tab Number of GO terms for the species 1 \cr
+#'   SP2 \tab Number of GO terms for the species 2 \cr
+#'   SHARED \tab Number of GO terms shared or co-ocurring between the categories \cr
+#'   SHARED_WEIGHT \tab Shared weight for the edge \cr
+#'   }
+#'
+#'   Node list columns:
+#'   \tabular{rr}{
+#'   Column \tab Description \cr
+#'   CAT\tab Category name \cr
+#'   CAT_WEIGHT  \tab Node weight \cr
+#'   SHARED_WEIGHT  \tab Shared weight for the node \cr
+#'   COMBINED_WEIGHT \tab Combined weight for the node \cr
+#'   }
+#'
+#'  (GO):
+#'
+#'   Edges list columns:
+#'   \tabular{rr}{
+#'   Column \tab Description \cr
+#'   SOURCE and TARGET \tab The source and target GO terms (Nodes in the edge) \cr
+#'   FEATURE \tab The number of Categories where both GO Terms were found \cr
+#'   SP \tab Species where the GO terms was found (Species 1, Species 2 or Shared) \cr
+#'   WEIGHT \tab Edge weight \cr
+#'   }
+#'   Node list columns:
+#'
+#'   \tabular{rr}{
+#'   Column \tab Description \cr
+#'   GO \tab GO term node name \cr
+#'   GO_WEIGHT \tab Node weight \cr
+#'   }
 #'
-#' @return This function will return a list with two slots: edges and nodes. Edges represent an edge list and their weights and
-#'  nodes which represent the nodes and their respective weights (weights, shared)
 #' @importFrom utils combn setTxtProgressBar txtProgressBar
 #' @importFrom parallel makeCluster parLapplyLB stopCluster detectCores
 #' @importFrom igraph graph_from_data_frame write.graph
-#'
+#' @import mathjaxr
 #' @export
 
 graph_two_GOspecies <-
@@ -74,7 +131,8 @@ graph_two_GOspecies <-
            saveGraph = FALSE,
            option = "Categories",
            numCores=2,
-           outdir = NULL) {
+           outdir = NULL,
+           filename = NULL) {
 
     x_det <- NULL
     x_det <- parallel::detectCores()
@@ -96,6 +154,14 @@ graph_two_GOspecies <-
       stop("Please select saveGraph=TRUE to save your graph")
     }
 
+
+    if (isTRUE(saveGraph) & !is.null(outdir) & is.null(filename)) {
+      message(paste("Your filename will be saved as GO_TWO_SP.graphml or CAT_TWO_SP.graphml
+            dependent of the option selected in the path:",outdir))
+      message("please provide a filename if you want to avoid this behavior")
+    }
+
+
     if (numCores > x_det) {
       stop("Number of cores exceed the maximum allowed by the machine, use a coherent number of cores such as four")
     }
@@ -272,6 +338,23 @@ graph_two_GOspecies <-
 
       x_att <- do.call(rbind,x_att)
 
+
+      # COMBINED WEIGHT
+
+      GO_WEIGHT_N <- (x_att$GO_WEIGHT-min(x_att$GO_WEIGHT,na.rm = T))/
+          (max(x_att$GO_WEIGHT,na.rm = T)-min(x_att$GO_WEIGHT,na.rm = T))
+
+      SHARED_WEIGHT_N <-  (x_att$SHARED_WEIGHT-min(x_att$SHARED_WEIGHT,na.rm = T))/
+           (max(x_att$SHARED_WEIGHT,na.rm =T)-min(x_att$SHARED_WEIGHT,na.rm = T))
+
+
+      x_att$COMBINED_WEIGHT <- (GO_WEIGHT_N + SHARED_WEIGHT_N) - 1
+
+
+        #((x_att$GO_WEIGHT/max(x_att$GO_WEIGHT,na.rm = T))+
+        #(x_att$SHARED_WEIGHT/max(x_att$SHARED_WEIGHT,na.rm = T)))-1
+      colnames(x_att) <- c("CAT","CAT_WEIGHT","SHARED_WEIGHT","COMBINED_WEIGHT")
+
       res <- list(nodes=x_att,edges=res)
 
 
@@ -349,25 +432,43 @@ graph_two_GOspecies <-
 
     if (isTRUE(saveGraph)) {
       if (isTRUE(option == "Categories")) {
-        x1 <- igraph::graph_from_data_frame(res$edges, directed = FALSE,vertices = res$nodes)
-        message(paste("saving ",paste0(outdir, "/", "CAT_TWO_SP.graphml")))
+        if(is.null(filename)){
+
+          message(paste("saving ",paste0(outdir, "/", "CAT_TWO_SP.graphml")))
+          x1 <- igraph::graph_from_data_frame(res$edges, directed = FALSE,vertices =  res$nodes)
+          igraph::write.graph(x1,
+                              file = paste0(outdir, "/", "CAT_TWO_SP.graphml"),
+                              format = "graphml")
+        } else {
+
+          message(paste("saving ",paste0(outdir, "/",filename,".graphml")))
+          x1 <- igraph::graph_from_data_frame(res$edges, directed = FALSE,vertices =  res$nodes)
+          igraph::write.graph(x1,
+                              file = paste0(outdir, "/",filename,".graphml"),
+                              format = "graphml")
+
+        }
 
-        igraph::write.graph(
-          x1,
-          file = paste0(outdir, "/", "CAT_TWO_SP.graphml"),
-          format = "graphml"
-        )
       } else if(isTRUE(option =="GO")){
+        if(is.null(filename)){
 
+          message(paste("saving ",paste0(outdir, "/", "GO_TWO_SP.graphml")))
+          x2 <- igraph::graph_from_data_frame(res$edges, directed = FALSE,vertices =  res$nodes)
+          igraph::write.graph(x2,
+                              file = paste0(outdir, "/", "GO_TWO_SP.graphml"),
+                              format = "graphml")
+        } else {
 
-        x2 <- igraph::graph_from_data_frame(res$edges, directed = FALSE,vertices = res$nodes)
-        message(paste("saving ",paste0(outdir, "/", "GO_TWO_SP.graphml")))
-        igraph::write.graph(
-          x2,
-          file = paste0(outdir, "/", "GO_TWO_SP.graphml"),
-          format = "graphml"
-        )
+          message(paste("saving ",paste0(outdir, "/",filename,".graphml")))
+          x2 <- igraph::graph_from_data_frame(res$edges, directed = FALSE,vertices =  res$nodes)
+          igraph::write.graph(x2,
+                              file = paste0(outdir, "/",filename,".graphml"),
+                              format = "graphml")
+
+        }
       }
+    } else {
+      message("Saving as edges and nodes lists")
     }
 
     return(res)
